if [ $# -ne 4 ]; then
    echo Error: Wrong number of arguments
    echo Usage: $0 [input network] [input network format] [node centrality measure] [output dir]
    echo Options for [input network format]: E - Edge list, L - LEDA
    echo Options for [node centrality measure]: B - Betweenness, C - Closeness, CC - Clustering coefficient, D - Degree, E - Eccentricity, G - GDC, K - k-coreness, A - Each of B, C, CC, D, E, G, and K
    exit
fi

inputNetwork=$1
inputFormat=$2
centrality=$3
outputDir=$4

tmpDir="tmp"

if [ ! -d $tmpDir ]; then
    mkdir $tmpDir
fi

if [ ! -f $inputNetwork ]; then
    echo Error: Input network $inputNetwork not found
    exit
fi

outputDir=${outputDir%/}
if [ ! -d $outputDir ]; then
    mkdir $outputDir
fi

outputFile=$(basename $inputNetwork)
outputFile=${outputFile%\.*}

case "$inputFormat" in 
    "E" )
        ./bin/list2leda $inputNetwork > $tmpDir/$outputFile.gw
        ./bin/sanitize $tmpDir/$outputFile.gw > $tmpDir/$outputFile.1.gw
        mv $tmpDir/$outputFile.1.gw $tmpDir/$outputFile.gw
        ;;
    "L" )
        ./bin/sanitize $inputNetwork > $tmpDir/$outputFile.gw
        ;;
    * )
        echo Error: Invalid option for [input network format]
        echo Options for [input network format]: E - Edge list, L - LEDA
        exit
        ;;
esac

case "$centrality" in
    "B" )
        sh script/BetwProg.sh $tmpDir/$outputFile.gw $outputDir/$outputFile.betwc
        echo Output of between centrality is written into $outputDir/$outputFile.betwc 
        ;;
    "C" )
        ./bin/sh_path $tmpDir/$outputFile.gw $tmpDir/$outputFile.shpath
        ./bin/closec-and-ecc $tmpDir/$outputFile.shpath $outputDir/$outputFile.closec 1
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.closec
        echo Output of closeness centrality is written into $outputDir/$outputFile.closec    
        rm $tmpDir/$outputFile.shpath
        ;;
    "CC" )
        ./bin/ncount $tmpDir/$outputFile.gw $tmpDir/$outputFile 1>/dev/null 2>&1
        rm $tmpDir/$outputFile
        rm $tmpDir/$outputFile.cl*
        rm $tmpDir/$outputFile.gr_freq
		cut -d ' ' -f1,2,5 $tmpDir/$outputFile.ndump2 > $tmpDir/$outputFile.125.ndump2
		./bin/clust-coeff $tmpDir/$outputFile.125.ndump2 $outputDir/$outputFile.clusc
		rm $tmpDir/$outputFile.125.ndump2
        rm $tmpDir/$outputFile.ndump2
        echo Output of clustering coefficient centrality is written into $outputDir/$outputFile.clusc
        ;;
    "D" )
        ./bin/ncount $tmpDir/$outputFile.gw $tmpDir/$outputFile 1>/dev/null 2>&1
        rm $tmpDir/$outputFile
        rm $tmpDir/$outputFile.cl*
        rm $tmpDir/$outputFile.gr_freq
		cut -d ' ' -f1,2 $tmpDir/$outputFile.ndump2 > $outputDir/$outputFile.degc
        rm $tmpDir/$outputFile.ndump2
        echo Output of degree centrality is written into $outputDir/$outputFile.degc
        ;;
    "E" )
        ./bin/sh_path $tmpDir/$outputFile.gw $tmpDir/$outputFile.shpath
        ./bin/closec-and-ecc $tmpDir/$outputFile.shpath $outputDir/$outputFile.ecc 2
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.ecc
        echo Output of eccentricity centrality is written into $outputDir/$outputFile.ecc
        rm $tmpDir/$outputFile.shpath
        ;;
    "G" )
        ./bin/ncount $tmpDir/$outputFile.gw $tmpDir/$outputFile 1>/dev/null 2>&1
        rm $tmpDir/$outputFile
        rm $tmpDir/$outputFile.cl*
        rm $tmpDir/$outputFile.gr_freq
        ./bin/gdc $tmpDir/$outputFile.ndump2 $outputDir/$outputFile.gdc
        rm $tmpDir/$outputFile.ndump2
        echo Output of graphlet degree centrality is written into $outputDir/$outputFile.gdc
        ;;
    "K" )
        ./bin/leda2list $tmpDir/$outputFile.gw $tmpDir/$outputFile.el
        ./bin/kCoreness $tmpDir/$outputFile.el $outputDir/$outputFile.kc
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.kc
        rm $tmpDir/$outputFile.el
        echo Output of k-coreness centrality is written into $outputDir/$outputFile.kc
        ;;
    "A" )
        sh script/BetwProg.sh $tmpDir/$outputFile.gw $outputDir/$outputFile.betwc
        echo Output of between centrality is written into $outputDir/$outputFile.betwc
         
        ./bin/sh_path $tmpDir/$outputFile.gw $tmpDir/$outputFile.shpath
        ./bin/closec-and-ecc $tmpDir/$outputFile.shpath $outputDir/$outputFile.closec 1
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.closec
        echo Output of closeness centrality is written into $outputDir/$outputFile.closec    

        ./bin/ncount $tmpDir/$outputFile.gw $tmpDir/$outputFile 1>/dev/null 2>&1
        rm $tmpDir/$outputFile
        rm $tmpDir/$outputFile.cl*
        rm $tmpDir/$outputFile.gr_freq
		cut -d ' ' -f1,2,5 $tmpDir/$outputFile.ndump2 > $tmpDir/$outputFile.125.ndump2
		./bin/clust-coeff $tmpDir/$outputFile.125.ndump2 $outputDir/$outputFile.clusc
		rm $tmpDir/$outputFile.125.ndump2
        echo Output of clustering coefficient centrality is written into $outputDir/$outputFile.clusc

		cut -d ' ' -f1,2 $tmpDir/$outputFile.ndump2 > $outputDir/$outputFile.degc
        echo Output of degree centrality is written into $outputDir/$outputFile.degc

        ./bin/closec-and-ecc $tmpDir/$outputFile.shpath $outputDir/$outputFile.ecc 2
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.ecc
        echo Output of eccentricity centrality is written into $outputDir/$outputFile.ecc

        rm $tmpDir/$outputFile.shpath
        ./bin/gdc $tmpDir/$outputFile.ndump2 $outputDir/$outputFile.gdc
        rm $tmpDir/$outputFile.ndump2
        echo Output of graphlet degree centrality is written into $outputDir/$outputFile.gdc

        ./bin/leda2list $tmpDir/$outputFile.gw $tmpDir/$outputFile.el
        ./bin/kCoreness $tmpDir/$outputFile.el $outputDir/$outputFile.kc
        ./bin/zero-degree $tmpDir/$outputFile.gw >> $outputDir/$outputFile.kc
        rm $tmpDir/$outputFile.el
        echo Output of k-coreness centrality is written into $outputDir/$outputFile.kc
        ;;
    *)
        echo Error: Invalid option for [node centrality measure]
        echo Options for [node centrality measure]: B - Betweenness, C - Closeness, CC - Clustering coefficient, D - Degree, E - Eccentricity, G - GDC, K - k-coreness, A - Each of B, C, CC, D, E, G, and K
        exit
        ;;
esac

rm $tmpDir/$outputFile.gw

if [ ! "$(ls -A $tmpDir)" ]; then
	rm -r $tmpDir
fi
